# @summary A short summary of the purpose of this class
#
# A description of what this class does
#
# @example
#   include secure_iis_cis::cis_3_2
class secure_iis_cis::cis_3_2(
  Boolean $enforced = true,
) {
  if($enforced) {
    exec { 'Ensure debug is off for server':
      command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST' -filter 'system.web/compilation' -name 'debug' -value 'False'",
      unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST' -filter 'system.web/compilation' -name 'debug') -ne 'False') { exit 1 }",
      provider => powershell,
    }

    $facts['iis_sites'].each | Hash $site | {
      exec { "Delete local compilation nodes exist for ${site['name']}":
        command  => epp('secure_iis_cis/DeleteLocalCompilationNodes.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/LocalCompilationNodesExist.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure compilation node exists for ${site['name']}":
        command  => epp('secure_iis_cis/CreateCompilationNode.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/CompilationNodeExists.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure debug is off for site ${site['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/compilation' -name 'debug' -value 'False'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/compilation' -name 'debug') -ne 'False') { exit 1 }",
        provider => powershell,
      }
    }

    $facts['iis_apps'].each | Hash $app | {
      exec { "Delete local compilation nodes exist for ${app['name']}":
        command  => epp('secure_iis_cis/DeleteLocalCompilationNodes.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/LocalCompilationNodesExist.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure compilation node exists for ${app['name']}":
        command  => epp('secure_iis_cis/CreateCompilationNode.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/CompilationNodeExists.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure debug is off for app ${app['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/compilation' -name 'debug' -value 'False'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/compilation' -Recurse -name 'debug') -ne 'False') { exit 1 }",
        provider => powershell,
      }
    }
  }
}
