# @summary A short summary of the purpose of this class
#
# A description of what this class does
#
# @example
#   include secure_iis_cis::cis_3_3
class secure_iis_cis::cis_3_3(
  Boolean $enforced = true,
) {
  if($enforced) {
    exec { 'Turn off custom errors for server':
      command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST' -filter 'system.web/customErrors' -name 'mode' -value 'RemoteOnly'",
      unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST' -filter 'system.web/customErrors' -name 'mode') -ne 'RemoteOnly') { exit 1 }",
      provider => powershell,
    }

    $facts['iis_sites'].each | Hash $site | {
      exec { "Delete local custom error nodes exist for ${site['name']}":
        command  => epp('secure_iis_cis/DeleteLocalCustomErrorNodes.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/LocalCustomErrorNodesExist.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure custom errors node exists for ${site['name']}":
        command  => epp('secure_iis_cis/CreateCustomErrorsNode.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/CustomErrorsNodeExists.ps1', { 'physicalpath' => "${site['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Turn off custom errors for site ${site['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/customErrors' -name 'mode' -value 'RemoteOnly'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/customErrors' -name 'mode') -ne 'RemoteOnly') { exit 1 }",
        provider => powershell,
      }
    }

    $facts['iis_apps'].each | Hash $app | {
      exec { "Delete local custom error nodes exist for ${app['name']}":
        command  => epp('secure_iis_cis/DeleteLocalCustomErrorNodes.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/LocalCustomErrorNodesExist.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Ensure custom errors node exists for ${app['name']}":
        command  => epp('secure_iis_cis/CreateCustomErrorsNode.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        unless   => epp('secure_iis_cis/CustomErrorsNodeExists.ps1', { 'physicalpath' => "${app['physical_path']}\\web.config" }),
        provider => powershell,
      }

      exec { "Turn off custom errors for app ${app['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/customErrors' -name 'mode' -value 'RemoteOnly'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/customErrors' -name 'mode') -ne 'RemoteOnly') { exit 1 }",
        provider => powershell,
      }
    }
  }
}
