# @summary A short summary of the purpose of this class
#
# A description of what this class does
#
# @example
#   include secure_iis_cis::cis_3_9
class secure_iis_cis::cis_3_9(
  Boolean $enforced = true,
) {
  if($enforced) {
    exec { 'Ensure MachineKey validation method configured':
      command  => 'Set-WebConfigurationProperty -pspath "MACHINE/WEBROOT" -filter "system.web/machineKey" -name "validation" -value "HMACSHA256"',
      unless   => 'if ((Get-WebConfigurationProperty -pspath "MACHINE/WEBROOT" -filter "system.web/machineKey" -name "validation") -ne "HMACSHA256") { exit 1 }',
      provider => powershell,
    }

    $facts['iis_sites'].each | Hash $site | {
      exec { "Ensure MachineKey validation method configured for site ${site['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/machineKey' -name 'validation' -value 'HMACSHA256'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${site['name']}' -filter 'system.web/machineKey' -name 'validation') -ne 'HMACSHA256') { exit 1 }",
        provider => powershell,
      }
    }

    $facts['iis_apps'].each | Hash $app | {
      exec { "Ensure MachineKey validation method configured for app ${app['name']}":
        command  => "Set-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/machineKey' -name 'validation' -value 'HMACSHA256'",
        unless   => "if ((Get-WebConfigurationProperty -pspath 'MACHINE/WEBROOT/APPHOST/${app['site']}${app['name']}' -filter 'system.web/machineKey' -name 'validation') -ne 'HMACSHA256') { exit 1 }",
        provider => powershell,
      }
    }
  }
}
