# @summary A short summary of the purpose of this class
#
# A description of what this class does
#
# @example
#   include secure_iis_cis
class secure_iis_cis {
  file { 'C:/tmp':
    ensure => directory,
  }

  file { 'C:/tmp/GetIISSites.ps1':
    ensure  => file,
    content => file('secure_iis_cis/GetIISSites.ps1')
  }

  file { 'C:/tmp/GetAppPools.ps1':
    ensure  => file,
    content => file('secure_iis_cis/GetAppPools.ps1')
  }

  file { 'C:/tmp/GetWebApplications.ps1':
    ensure  => file,
    content => file('secure_iis_cis/GetWebApplications.ps1')
  }

  $blank_web_config = @("WEBCONFIG"/L)
    <?xml version="1.0" encoding="UTF-8"?>
    <configuration>
      <system.web>
        <authentication>
          <forms cookieless="UseCookies" requireSSL="true" />
        </authentication>
        <httpCookies httpOnlyCookies="true" />
        <customErrors mode="RemoteOnly" />
        <compilation debug="false" />
      </system.web>
    </configuration>
    | WEBCONFIG

  $facts['iis_apps'].each | Hash $app | {
    file { "${app['physical_path']}/web.config":
      ensure  => file,
      content => $blank_web_config,
      replace => false,
    }
  }

  include ::secure_iis_cis::cis_1_2
  include ::secure_iis_cis::cis_1_4
  include ::secure_iis_cis::cis_2_3
  include ::secure_iis_cis::cis_2_4
  include ::secure_iis_cis::cis_3_1
  include ::secure_iis_cis::cis_3_2
  include ::secure_iis_cis::cis_3_3
  include ::secure_iis_cis::cis_3_7
  include ::secure_iis_cis::cis_3_9
  include ::secure_iis_cis::cis_4_4
  include ::secure_iis_cis::cis_4_6
}
